<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>
		
<form action="index.php?amn=grp_edit" method="post" name="frm" id="id_frm" enctype="multipart/form-data">
<input type="hidden" name="group_id" value="<?php if (isset($group['group_id'])) { echo $group['group_id'];}?>" />

<?php
if (isset($display) && $display == "policy") {
?>
<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_policy'];?></h1>
		</div>
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table cellspacing="1" cellpadding="0" border="0" width="100%">
				<tr>
					<td>
						<b><label for="id_group_policy" style="width:300px"><?php echo $lang['txt_title_policy'];?></label></b><br />
					</td>
					<td>
						<?php
						$gui_expert_editor = "id_group_policy";
						include($template_path_core . "inc/form_gui_html_editor.inc.php");
						?>
					</td>
				</tr>
			</table>
				
			<table cellspacing="1" cellpadding="0" border="0" width="100%">
				<tr>
					<td width="1">
						<textarea id="id_group_policy" name="group_policy" cols="72" rows="8" style="width:480px;" onKeyUp="AMEditorSync(this.value, 'wysiwyg_editor');"><?php if (isset($group['group_policy'])) { echo $group['group_policy'];}?></textarea>
						<br />
					</td>
					<td>
						<br />
					</td>
					<td rowspan="2" valign="top" width="90%">
						<div id="editor_help"><?php echo $lang['txt_help_default'];?></div>
					</td>
				</tr>
				<tr>
					<td width="1">
						<iframe id="wysiwyg_editor" name="wysiwyg_editor" style="height:100px; width:480px;" frameborder="0" width="580"  scrolling="yes"  height="100">
			
						</iframe>
					</td>
					<td valign="top" width="20">
						<img src="<?php echo $template_path_core;?>img/arrow_up.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize();" /><br />
						<img src="<?php echo $template_path_core;?>img/arrow_down.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize('minus');" /><br />
						<img src="<?php echo $template_path_core;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
					</td>
				</tr>
			</table>
			
			<script language="javascript" type="text/javascript">
				var wysiwygHeight = 100;
				var thisEditor = new AMEditor('id_group_policy', 'wysiwyg_editor');
			</script>
			
			<hr />
			
			<p align="right">
				<input type="submit" name="preview_policy" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				
				<input type="submit" name="update_policy" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_policy'];?>" />
				<br />
			</p>
			
			<?php
			if (isset($group['display_group_policy'])) {
			?>
			<p>
				<?php echo $group['display_group_policy'];?><br />
			</p>
			<?php }?>
		</div>
	</div>
</div>
	
<?php
}
else {
?>

<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_group_edit'];?></h1>
		</div>
	</div>
	
	<div class="box_mid">
		<div class="content">
			<p>
				<b><?php echo $lang['txt_title_intro'];?></b><br />
			</p>
			
			<p>
				<label for="id_group_title"><?php echo $lang['txt_title'];?></label>
				<input id="id_group_title" class="input" type="text" name="group_title" size="24" style="width:480px;" value="<?php if (isset($group['group_title'])) { echo $group['group_title'];}?>" />
				&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
				<br />
			</p>

			<p>
				<label for="id_group_synopsis"><?php echo $lang['txt_synopsis'];?></label>
				<textarea id="id_group_synopsis" name="group_synopsis" cols="22" style="width:480px;" rows="2"><?php if (isset($group['group_synopsis'])) { echo $group['group_synopsis'];}?></textarea>
				<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
				<br />
			</p>


			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<label for="id_network"><?php echo $lang['txt_age'];?></label>
							<?php
							if (isset($group['group_from_age'])) {
							    $from_txt = $group['group_from_age'];
							}
							else {
								$from_txt = "";
							}
							
							if (isset($group['group_to_age'])) {
							    $to_txt = $group['group_to_age'];
							}
							else {
								$to_txt = "";
							}
							
							?>
							<input type="text" size="5" name="group_from_age" class="input1" value="<?php echo $from_txt;?>">
							<input type="text" size="5" name="group_to_age" class="input1" value="<?php echo $to_txt;?>">
							<br />
						</p>
						
						<p>
							<label for="id_pref_lang"><?php echo $lang['txt_lang'];?></label>
							<select name="language_id" id="id_pref_lang">
								<?php foreach($lang['arr_lang_name'] as $key => $i): ?>
								<option value="<?php echo $key;?>"><?php echo ucfirst($i);?></option>
								<?php endforeach; ?>
							</select><br />
						</p>
						
						<?php
						if (isset($locations)) {
						?>
						<p>
							<label for="id_location"><?php echo $lang['txt_location'];?></label>
							<select id="id_location" name="location_id">
							<option value="0"><?php echo $lang['txt_location_none'];?></option>
								
							<?php
							foreach($locations as $key => $i):
							$selected="";
							if (isset($group['location_id']) && $group['location_id'] == $i['location_id']) {
								$selected = " selected=\"selected\"";
							}
							?>
							<option value="<?php echo $i['location_id'];?>"<?php echo $selected;?>><?php echo $i['location_name'];?></option>
							<?php
							endforeach;
							?>
							</select>
						</p>
						<?php }?>
						
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" /><br />
					</td>
					<td valign="top" width="50%">
						<script type="text/javascript">
						function showMembershipTypes(id) {
							var displaystate = 'none';
							
							if (id.value == 4) {
								displaystate = 'block';
							}
							
							objShowHide('id_membership_type', displaystate);
						}
						</script>
						
						<p>
							<label for="id_group_type"><?php echo $lang['txt_participation'];?></label>
							<?php
							// if this is set to membership type and we do not have permission to change this
							// we just print out that
							if (isset($group['group_type']) && $group['group_type'] == $group_config['type']['membership_type'] && $core_config['resource']['user']['mem_visible'] & ~$_SESSION['user_core_permission']) {
								echo $lang['group_type'][$group['group_type']];
								if (!empty($group['membership_type_ids'])) {
									$prnt = "<br /><i>(";
									foreach ($group['membership_type_ids'] as $keymt => $mt):
										$prnt .= $lang['membership_type'][$mt['membership_type_id']] . ", ";
									endforeach;
		
									$prnt = substr ($prnt, 0, -2) . ")</i><br />";
									echo $prnt;
								}
							}
							else {
							?>
							<select id="id_group_type" name="group_type" style="width:160px;" onChange="javascript:showMembershipTypes(this);">
								<?php
								if (isset($group_config['type'])) {
								foreach ($group_config['type'] as $key => $i):
		
								// check to see if we are allowed to set membership types
								if ($i == $group_config['type']['membership_type'] &&  $core_config['resource']['user']['mem_visible'] & ~$_SESSION['user_core_permission']) {
									break;
								}
						
								$selected = "";
								if (isset($group['group_type']) && $group['group_type'] == $i) {
									$selected = "selected=\"selected\"";
								}
								?>
								<option value="<?php echo $i;?>" <?php echo $selected;?>><?php echo $lang['group_type'][$i];?></option>
								<?php
								endforeach;
								}
								?>
							</select>
							<?php }?>
						</p>
				
						<?php
						if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
						?>
						<p id="id_membership_type">
							<?php
							if (isset($lang['membership_type'])) {
							foreach ($lang['membership_type'] as $key => $i):
	
							$selected = "";
							
							if (!empty($group['membership_type_ids'])) { 
								foreach ($group['membership_type_ids'] as $keymt => $mt):
									if ($mt['membership_type_id'] == $key) {
										$selected = "checked=\"checked\"";
										break;
									}
								endforeach;
							}
							?>
							<label></label>
							<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
							<?php
							endforeach;
							}
							?>
						</p>
				
						<script type="text/javascript">
							var id = document.getElementById('id_group_type');
							showMembershipTypes(id);
						</script>
						<?php }?>
				
						
						<script type="text/javascript">
						function showUnixTitle(id) {
							var displaystate = 'none';
							
							if (id.value == 16) {
								displaystate = 'block';
							}
							
							objShowHide('group_unix_title_div', displaystate);
						}
						</script>
						
						<?php if (empty($group['group_id'])) { ?>
						<p>
							<label for="identity_id"><?php echo $lang['txt_my_identity']; ?></label>
							<select name="identity_id">
							<?php foreach($identities as $i): ?>
								<?php 
									$selected = '';
									if (!empty($_REQUEST['identity_id'])) {
										if ($i['identity_id'] == $_REQUEST['identity_id']) {
											$selected = "selected=\"selected\"";
										}
									}
								?>
								<option value="<?php echo $i['identity_id']; ?>" <?php echo $selected; ?>><?php echo $i['identity_name']; ?></option>
							<?php endforeach; ?>
							</select>
						</p>
						<?php } ?>
						
						<p>
							<label for="id_level_id"><?php echo $lang['txt_publish'];?></label>
							<select id="id_level_id" name="level_id" style="width:160px;" onChange="javascript:showUnixTitle(this);">
								<?php
								if (isset($lang['group_level'])) {
								foreach ($lang['group_level'] as $key => $i):
								
								$selected = "";
								if (isset($group['level_id']) && $group['level_id'] == $key) {
									$selected = "selected=\"selected\"";
								}
								?>
								<option value="<?php echo $key;?>" <?php echo $selected;?>><?php echo $i;?></option>
								<?php
								endforeach;
								}
								?>
							</select>
						</p>
						
						<p id="group_unix_title_div">
							<label for="id_group_unix_title"><?php echo $lang['txt_unix_title'];?></label>
							<input id="id_group_unix_title" class="input" type="text" name="group_unix_title" size="24" value="<?php if (isset($group['group_unix_title'])) { echo $group['group_unix_title'];}?>" />
							<br />
						</p>
						
						<script type="text/javascript">
							var id = document.getElementById('id_level_id');
							showUnixTitle(id);
						</script>
						
						
					</td>
				</tr>
			</table>
			
			<hr />

			<p>
				<b><?php echo $lang['txt_title_create'];?></b><br />
			</p>
			
			<table cellspacing="1" cellpadding="0" border="0" width="100%">
				<tr>
					<td>
						<label for="id_subject_body"><?php echo $lang['txt_body'];?></label><br />
					</td>
					<td>
						<?php
						$gui_expert_editor = "id_subject_body";
						include($template_path_core . "inc/form_gui_html_editor.inc.php");
						?>
					</td>
				</tr>
			</table>
				
			<table cellspacing="1" cellpadding="0" border="0" width="100%">
				<tr>
					<td width="1">
						<textarea id="id_group_body" name="group_body" cols="72" rows="8" style="width:480px;" onKeyUp="AMEditorSync(this.value, 'wysiwyg_editor');"><?php if (isset($group['group_body'])) { echo $group['group_body'];}?></textarea>
				<br />
					</td>
					<td>
						<br />
					</td>
					<td rowspan="2" valign="top" width="90%">
						<div id="editor_help"><?php echo $lang['txt_help_default'];?></div>
					</td>
				</tr>
				<tr>
					<td width="1">
						<iframe id="wysiwyg_editor" name="wysiwyg_editor" style="height:100px; width:480px;" frameborder="0" width="580"  scrolling="yes"  height="100">
			
						</iframe>
					</td>
					<td valign="top" width="20">
						<img src="<?php echo $template_path_core;?>img/arrow_up.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize();" /><br />
						<img src="<?php echo $template_path_core;?>img/arrow_down.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize('minus');" /><br />
						<img src="<?php echo $template_path_core;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
					</td>
				</tr>
			</table>
			
			<script language="javascript" type="text/javascript">
				var wysiwygHeight = 100;
				var thisEditor = new AMEditor('id_group_body', 'wysiwyg_editor');
			</script>
			
			<hr />
			
			<p>
				<b><?php echo $lang['txt_title_image'];?></b><br />
			</p>

			<?php
			if (isset($images)) {
			?>
			<div style="overflow: auto; width:710px;">
			<table cellspacing="0" cellpadding="2" border="0">
			<tr>
				<td valign="top" align="center">
					<?php echo $lang['txt_none'];?><br />
					<input type="radio" name="file_id" value="0" checked="checked" /><br />
					<img src="<?php echo $template_path_core;?>img/pixel.png" width="60" height="1" alt="" border="0" /><br />
				</td>
				<?php
				foreach($images as $i):
				$selected = "";
				if (isset($group['file_id']) && $group['file_id'] == $i['file_id']) {
					$selected = "checked=\"checked\"";
				}
				?>
				<td valign="top" align="center">
					<img class="picture" src="get_file.php?file=<?php echo $i['file_md5_name_view']; ?>" alt="<?php echo $i['file_save_name']; ?>"/><br />
					<input type="radio" name="file_id" value="<?php echo $i['file_id'];?>" <?php echo $selected;?> /><br />
				</td>
				<?php
				endforeach;
				?>
			</tr>
			</table>
			</div>
			<?php }?>
			
			<br />

			<p>
				<label for="frm_file"><?php echo $lang['txt_file_to_upload']; ?></label>
				<input type="file" name="frm_file" id="frm_file" class="input1" /><br />
			</p>

			<p>
				<label for="frm_file_name"><?php echo $lang['txt_file_to_upload_name']; ?></label>
				<input type="text" name="frm_file_name" class="input1" id="frm_file_name" value="<?php echo isset($_REQUEST['update'], $selected_file[0]['file_save_name']) ? $selected_file[0]['file_save_name'] : ''; ?>"/>
			</p>
			
			<hr />
			
			<p>
				<b><?php echo $lang['txt_title_save'];?></b><br />
			</p>
			
			<p align="right">
				<input type="submit" name="preview_group" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				
				<?php
				if (!empty($group['group_id'])) {
				?>
				<input type="submit" name="update_group" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
				<?php
				}
				else {
				?>
				<input type="submit" name="insert_group" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<?php }?>
				<br />
			</p>
			
			<?php
			if (isset($group['display_group_body'])) {
			?>
			<p>
				<?php echo $group['display_group_body'];?><br />
			</p>
			<?php }?>
		</div>
	</div>
</div>
<?php }?>
</form>